==> org.Bt.eg.db_2.2.6.tar.gz: org.Bt.eg.db/man/org.Bt.eg_dbconn.Rd <==
\name{org.Bt.eg_dbconn}

\alias{org.Bt.eg_dbconn}
\alias{org.Bt.eg_dbfile}
\alias{org.Bt.eg_dbschema}
\alias{org.Bt.eg_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  org.Bt.eg_dbconn()
  org.Bt.eg_dbfile()
  org.Bt.eg_dbschema(file="", show.indices=FALSE)
  org.Bt.eg_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{org.Bt.eg_dbconn} returns a connection object to the package
  annotation DB.
  IMPORTANT: Don't call \code{\link[DBI]{dbDisconnect}} on the connection
  object returned by \code{org.Bt.eg_dbconn} or you will
  break all the \code{\link[AnnotationDbi]{AnnDbObj}} objects defined in this package!

  \code{org.Bt.eg_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{org.Bt.eg_dbschema} prints the schema definition of the
  package annotation DB.

  \code{org.Bt.eg_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{org.Bt.eg_dbconn}: a DBIConnection object representing an open
  connection to the package annotation DB.

  \code{org.Bt.eg_dbfile}: a character string with the path to the
  package annotation DB.

  \code{org.Bt.eg_dbschema}: none (invisible \code{NULL}).

  \code{org.Bt.eg_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI]{dbGetQuery}},
  \code{\link[DBI]{dbConnect}},
  \code{\link[AnnotationDbi]{dbconn}},
  \code{\link[AnnotationDbi]{dbfile}},
  \code{\link[AnnotationDbi]{dbschema}},
  \code{\link[AnnotationDbi]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "genes" table:
  dbGetQuery(org.Bt.eg_dbconn(), "SELECT COUNT(*) FROM genes")

  ## The connection object returned by org.Bt.eg_dbconn() was created with:
  dbConnect(SQLite(), dbname=org.Bt.eg_dbfile(), cache_size=64000, synchronous=0)

  org.Bt.eg_dbschema()

  org.Bt.eg_dbInfo()
}

\keyword{utilities}
\keyword{datasets}

==> org.Bt.eg.db_2.6.4.tar.gz: org.Bt.eg.db/man/org.Bt.eg_dbconn.Rd <==

\name{org.Bt.eg_dbconn}

\alias{org.Bt.eg_dbconn}
\alias{org.Bt.eg_dbfile}
\alias{org.Bt.eg_dbschema}
\alias{org.Bt.eg_dbInfo}


\title{Collect information about the package annotation DB}

\description{
  Some convenience functions for getting a connection object to (or collecting
  information about) the package annotation DB.
}

\usage{
  org.Bt.eg_dbconn()
  org.Bt.eg_dbfile()
  org.Bt.eg_dbschema(file="", show.indices=FALSE)
  org.Bt.eg_dbInfo()
}

\arguments{
  \item{file}{
    A connection, or a character string naming the file to print to (see
    the \code{file} argument of the \code{\link[base]{cat}} function for
    the details).
  }
  \item{show.indices}{
    The CREATE INDEX statements are not shown by default.
    Use \code{show.indices=TRUE} to get them.
  }
}

\details{
  \code{org.Bt.eg_dbconn} returns a connection object to the
  package annotation DB.  IMPORTANT: Don't call
  \code{\link[DBI:dbConnect]{dbDisconnect}} on the connection object
  returned by \code{org.Bt.eg_dbconn} or you will break all the
  \code{\link[AnnotationDbi:AnnDbObj-class]{AnnDbObj}} objects defined
  in this package!

  \code{org.Bt.eg_dbfile} returns the path (character string) to the
  package annotation DB (this is an SQLite file).

  \code{org.Bt.eg_dbschema} prints the schema definition of the
  package annotation DB.

  \code{org.Bt.eg_dbInfo} prints other information about the package
  annotation DB.
}

\value{
  \code{org.Bt.eg_dbconn}: a DBIConnection object representing an
  open connection to the package annotation DB.

  \code{org.Bt.eg_dbfile}: a character string with the path to the
  package annotation DB.

  \code{org.Bt.eg_dbschema}: none (invisible \code{NULL}).

  \code{org.Bt.eg_dbInfo}: none (invisible \code{NULL}).
}

\seealso{
  \code{\link[DBI:dbSendQuery]{dbGetQuery}},
  \code{\link[DBI:dbConnect]{dbConnect}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbconn}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbfile}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbschema}},
  \code{\link[AnnotationDbi:AnnDbObj-class]{dbInfo}}
}

\examples{
  ## Count the number of rows in the "genes" table:
  dbGetQuery(org.Bt.eg_dbconn(), "SELECT COUNT(*) FROM genes")

  ## The connection object returned by org.Bt.eg_dbconn() was
  ## created with:
  dbConnect(SQLite(), dbname=org.Bt.eg_dbfile(), cache_size=64000,
  synchronous=0)

  org.Bt.eg_dbschema()

  org.Bt.eg_dbInfo()
}

\keyword{utilities}
\keyword{datasets}
